@@ -1,3 +1,3 @@
 # Start MATLAB engine
-from .get_options import *
-from .matlab_wrapper import *
\ No newline at end of file
+from .matlab_wrapper import *
+from .mem_options import MEMOptions
\ No newline at end of file
